==> haskell-pretty-show-1.6.13-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pretty-show
version: 1.6.13
id: pretty-show-1.6.13-HOcTHr1BMsy3uFsQksDyt2
key: pretty-show-1.6.13-HOcTHr1BMsy3uFsQksDyt2
license: MIT
maintainer: iavor.diatchki@gmail.com
homepage: http://wiki.github.com/yav/pretty-show
synopsis: Tools for working with derived `Show` instances and generic
          inspection of values.
description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.
category: Text
author: Iavor S. Diatchki
exposed: True
exposed-modules:
    Text.Show.Pretty
hidden-modules: Text.Show.Html Text.Show.Parser Text.Show.Value
                Text.Show.PrettyVal Paths_pretty_show
abi: d4a495ffa504ce71de9acbc828dc1b19
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pretty-show-1.6.13
library-dirs: /usr/lib/ghc-8.0.1/site-local/pretty-show-1.6.13
data-dir: /usr/share/i386-linux-ghc-8.0.1/pretty-show-1.6.13
hs-libraries: HSpretty-show-1.6.13-HOcTHr1BMsy3uFsQksDyt2
depends:
    array-0.5.1.1 base-4.9.0.0 filepath-1.4.1.0 ghc-prim-0.5.0.0
    haskell-lexer-1.0.1-7aq6GXlIeo8GlO436Znra7 pretty-1.1.3.3
haddock-interfaces: /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html: /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-show-1.6.13-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pretty-show
version: 1.6.13
id: pretty-show-1.6.13-LSgpbeg7Zcd2id7s8ra4bM
key: pretty-show-1.6.13-LSgpbeg7Zcd2id7s8ra4bM
license: MIT
maintainer: iavor.diatchki@gmail.com
homepage: http://wiki.github.com/yav/pretty-show
synopsis: Tools for working with derived `Show` instances and generic
          inspection of values.
description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.
category: Text
author: Iavor S. Diatchki
exposed: True
exposed-modules:
    Text.Show.Pretty
hidden-modules: Text.Show.Html Text.Show.Parser Text.Show.Value
                Text.Show.PrettyVal Paths_pretty_show
abi: 7896be8e283744e252ffa99b87fb7bc9
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/pretty-show-1.6.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/pretty-show-1.6.13
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/pretty-show-1.6.13
hs-libraries: HSpretty-show-1.6.13-LSgpbeg7Zcd2id7s8ra4bM
depends:
    array-0.5.1.1 base-4.9.1.0 filepath-1.4.1.1 ghc-prim-0.5.0.0
    haskell-lexer-1.0.1-KbrNzOgvOlP3fb0pmnXx0E pretty-1.1.3.3
haddock-interfaces: /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html: /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
